@@ -4,8 +4,8 @@ L2Data Reader - A package for reading level 2 market data.
 
 __version__ = '0.1.0'
 
-from .reader import MarketDataReader, MarketDataHeader, IndexEntry
-from .models import Snapshot, Slice, MarketDataResult
+from .reader import MarketDataReader, MarketDataHeader, IndexEntry, MarketDataResult
+from .models import Snapshot, Slice
 from .exceptions import NoDataException, DataFormatException
 from .utils import time_to_milliseconds
 
@@ -94,5 +94,8 @@ __all__ = [
     'InvestorType',
     
     # 辅助函数
-    'time_to_milliseconds'
+    'time_to_milliseconds',
+
+    # 新增的 MarketDataWriter
+    'MarketDataWriter'
 ]
\ No newline at end of file
